Group of rules related to the overall layout.



# GEN-001: Consistent Font

**Applies to:**

- [Layout](/layout/layout)

**Fix State:** Not Automatically Fixable

```
No more than 2 fonts should be used in a report
```

# GEN-002: Consistent Title

**Applies to:**

__No sources specified__

**Fix State:** Not Automatically Fixable

```

All Sections should have a title in the top left quadrant of the report.
A title should be a text box visual.

```
